/*
This Source Code Form is subject to the terms of the Mozilla Public
License, v. 2.0. If a copy of the MPL was not distributed with this
file, You can obtain one at https://mozilla.org/MPL/2.0/.
*/

package main

import (
	"fmt"
	"net"
	"os"

	"idio.link/go/ipc/common"
	"idio.link/go/ipc/protocols"
)

func main() {
	log := common.NewLogger()
	abstract := "\000idio.link/go/ipc"
	c, err := net.Dial("unixpacket", abstract)
	if err != nil {
		panic(err)
	}
	defer func() {
		err := c.Close()
		if err != nil {
			log.Err("failed to close unix socket")
		}
	}()

	buf := make([]byte, 1024)
	cpm := protocols.NewClientPM()
	sdu := cpm.ReqAlloc(buf)
	if err := common.Send(c, sdu); err != nil {
		log.Fatal("send: %v", err)
	}
	sdu, err = common.Receive(c, buf)
	if err != nil {
		log.Fatal("receive: %w", err)
	}
	fmt.Printf("%q\n", sdu)

	log.Info("exiting: %v", err)
	os.Exit(1)
}
